@@ -14,6 +14,4 @@ def cli(debug):
 	util.debug(debug)
 
 # Command groups
-from sail import provision, deploy, database
-from sail import admin, backup, domain, logs
-from sail import ssh, wp, config
+from sail import provision, deploy, database, backups, domains, misc
